#### je_auto_control.core

* ctype input
* windows vk

#### je_auto_control.mouse

* mouse control

#### je_auto_control.keyboard

*  keyboard control

#### Detail

* Alpha version 0.0.3
* Run on windows
* pypi : https://pypi.org/project/je-auto-control/
* Github : https://github.com/JE-Chen/Python_AutoControl

##### you can use this lib to control windows mouse and keyboard